package glog

import "testing"

func TestGlog(t *testing.T) {
	Debug("hello")
	Info("hello")
	Warn("hello")
	Error("hello")
	DPanic("hello")
	//Panic("hello")
	//Fatal("hello")
	Debugf("hello")
	Infof("hello")
	Warnf("hello")
	Errorf("hello")
	DPanicf("hello")
	//Panicf("hello")
	//Fatalf("hello")
	Debugw("hello")
	Infow("hello")
	Warnw("hello")
	Errorw("hello")
	DPanicw("hello")
	//Panicw("hello")
	//Fatalw("hello")
}
